@@ -149,6 +149,12 @@ def get_parser(default_config_files, git_root):
             " not set)"
         ),
     )
+    group.add_argument(
+        "--show-thinking",
+        action=argparse.BooleanOptionalAction,
+        default=True,
+        help="Show reasoning content in the response (default: True)",
+    )
     group.add_argument(
         "--verify-ssl",
         action=argparse.BooleanOptionalAction,
@@ -241,6 +247,12 @@ def get_parser(default_config_files, git_root):
             " If unspecified, defaults to the model's max_chat_history_tokens."
         ),
     )
+    group.add_argument(
+        "--retries",
+        metavar="RETRIES_JSON",
+        help="Specify LLM retry configuration as a JSON string",
+        default=None,
+    )
 
     #######
     group = parser.add_argument_group("Customization Settings")
@@ -450,11 +462,16 @@ def get_parser(default_config_files, git_root):
         default=default_chat_history_file,
         help=f"Specify the chat history file (default: {default_chat_history_file})",
     ).complete = shtab.FILE
+    #########
+    group = parser.add_argument_group("Input settings")
     group.add_argument(
-        "--restore-chat-history",
+        "--terminal-setup",
         action=argparse.BooleanOptionalAction,
         default=False,
-        help="Restore the previous chat history messages (default: False)",
+        help=(
+            "Auto-configure terminal emulator for shift+enter support for new lines (default:"
+            " False)"
+        ),
     )
     ##########
     group = parser.add_argument_group("Output settings")
@@ -746,12 +763,6 @@ def get_parser(default_config_files, git_root):
         help="Show release notes on first run of new version (default: None, ask user)",
         default=None,
     )
-    group.add_argument(
-        "--install-main-branch",
-        action="store_true",
-        help="Install the latest version from the main branch",
-        default=False,
-    )
     group.add_argument(
         "--upgrade",
         "--update",
