@@ -67,12 +67,8 @@ class ModelCommand(BaseCommand):
 
             temp_coder = await Coder.create(**new_kwargs)
 
-            # Clear ALL messages for temp coder (start fresh)
-            ConversationManager.reset()
-
             # Re-initialize ConversationManager with temp coder
-            ConversationManager.initialize(temp_coder)
-            ConversationManager.clear_cache()
+            ConversationManager.initialize(temp_coder, reset=True, reformat=True)
 
             verbose = kwargs.get("verbose", False)
             if verbose:
@@ -87,35 +83,30 @@ class ModelCommand(BaseCommand):
                 temp_all_messages = ConversationManager.get_messages()
 
                 # Clear manager and restore original state
-                ConversationManager.reset()
-                ConversationManager.initialize(original_coder)
+                ConversationManager.initialize(original_coder, reset=True, reformat=True)
 
                 # Restore original messages with all metadata
                 for msg in original_all_messages:
-                    ConversationManager.add_message(
-                        msg.to_dict(),
-                        MessageTag(msg.tag),
-                        priority=msg.priority,
-                        timestamp=msg.timestamp,
-                        mark_for_delete=msg.mark_for_delete,
-                        hash_key=msg.hash_key,
-                    )
+                    if msg.tag in [MessageTag.DONE.value, MessageTag.CUR.value]:
+                        ConversationManager.add_message(
+                            message_dict=msg.message_dict,
+                            tag=MessageTag(msg.tag),
+                            priority=msg.priority,
+                            mark_for_delete=msg.mark_for_delete,
+                            force=True,
+                        )
 
                 # Append temp coder's DONE and CUR messages (but not other tags like SYSTEM)
                 for msg in temp_all_messages:
                     if msg.tag in [MessageTag.DONE.value, MessageTag.CUR.value]:
                         ConversationManager.add_message(
-                            msg.to_dict(),
-                            MessageTag(msg.tag),
+                            message_dict=msg.message_dict,
+                            tag=MessageTag(msg.tag),
                             priority=msg.priority,
-                            timestamp=msg.timestamp,
                             mark_for_delete=msg.mark_for_delete,
-                            hash_key=msg.hash_key,
+                            force=True,
                         )
 
-                # Move back cur messages with appropriate message
-                coder.move_back_cur_messages(f"Model {model_name} made those changes to the files.")
-
                 # Restore the original model configuration
                 from cecli.commands import SwitchCoderSignal
 
