@@ -42,7 +42,11 @@ from cecli.coders.base_coder import UnknownEditFormat
 from cecli.commands import Commands, SwitchCoderSignal
 from cecli.deprecated_args import handle_deprecated_model_args
 from cecli.format_settings import format_settings, scrub_sensitive_info
-from cecli.helpers.conversation import ConversationChunks
+from cecli.helpers.conversation import (
+    ConversationChunks,
+    ConversationManager,
+    MessageTag,
+)
 from cecli.helpers.copypaste import ClipboardWatcher
 from cecli.helpers.file_searcher import generate_search_path_list
 from cecli.history import ChatSummary
@@ -1215,6 +1219,9 @@ async def main_async(argv=None, input=None, output=None, force_git_root=None, re
                 if coder.mcp_manager.get_server("Local"):
                     await coder.mcp_manager.disconnect_server("Local")
 
+            for tag in [MessageTag.SYSTEM, MessageTag.EXAMPLES, MessageTag.STATIC]:
+                ConversationManager.clear_tag(tag)
+
             coder = await Coder.create(**kwargs)
 
             if switch.kwargs.get("show_announcements") is False:
