@@ -8,9 +8,9 @@ model_warnings = "https://cecli.dev/docs/llms/warnings.html"
 token_limits = "https://cecli.dev/docs/troubleshooting/token-limits.html"
 llms = "https://cecli.dev/docs/llms.html"
 large_repos = "https://cecli.dev/docs/faq.html#can-i-use-cecli-in-a-large-mono-repo"
-github_issues = "https://github.com/dwash96/aider-ce/issues/new"
+github_issues = "https://github.com/dwash96/cecli/issues/new"
 git_index_version = "https://github.com/Aider-AI/aider/issues/211"
 install_properly = "https://cecli.dev/docs/troubleshooting/imports.html"
-release_notes = "https://github.com/dwash96/aider-ce/releases/latest"
+release_notes = "https://github.com/dwash96/cecli/releases/latest"
 edit_formats = "https://cecli.dev/docs/more/edit-formats.html"
 models_and_keys = "https://cecli.dev/docs/troubleshooting/models-and-keys.html"
